==> estateplat-common-1.2.3-20180516.090746-86-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXmRel.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * .
 * <p/>
 * 项目关系
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-3-20
 */
@Table(name = "bdc_xm_rel")
public class BdcXmRel implements InsertVo,Serializable,BdcProid {
    @Id
    private String relid;//主键

    private String proid;//项目主键

    private String qjid;//权籍ID

    private String yproid;//原项目ID

    private String ydjxmly;//原登记项目来源 同bdcxm的xmly

    private String yqlid;//原权利ID


//zdd 暂时增加

//    private String tdid;//土地证ID
//
//    private String fwid;//房产证ID
//    private String lqid;//林权证主键
//
//    private String cqid;//草地所有权证ID
//
//    private String dyid;//抵押id
//
//    private String ygid;//预告id
//
//    private String cfid;//查封id
//
//    private String yyid;//异议id
//
//    private String gdqlid;//过渡权利id
//
//    //zdd 其他审批系统的业务主键，用于和不动产项目关联，spring aop 拦截时根据此字段是否有值进行拦截
//    private String gdproid;//过渡项目id
//
//    private String ybdcdyid;//原不动产单元id

//    public String getTdid() {
//        return tdid;
//    }
//
//    public void setTdid(String tdid) {
//        this.tdid = tdid;
//    }
//
//    public String getFwid() {
//        return fwid;
//    }
//
//    public void setFwid(String fwid) {
//        this.fwid = fwid;
//    }
//
//    public String getLqid() {
//        return lqid;
//    }
//
//    public void setLqid(String lqid) {
//        this.lqid = lqid;
//    }
//
//    public String getCqid() {
//        return cqid;
//    }
//
//    public void setCqid(String cqid) {
//        this.cqid = cqid;
//    }
//
//    public String getDyid() {
//        return dyid;
//    }
//
//    public void setDyid(String dyid) {
//        this.dyid = dyid;
//    }
//
//    public String getYgid() {
//        return ygid;
//    }
//
//    public void setYgid(String ygid) {
//        this.ygid = ygid;
//    }
//
//    public String getCfid() {
//        return cfid;
//    }
//
//    public void setCfid(String cfid) {
//        this.cfid = cfid;
//    }
//
//    public String getYyid() {
//        return yyid;
//    }
//
//    public void setYyid(String yyid) {
//        this.yyid = yyid;
//    }
//
//    public String getGdqlid() {
//        return gdqlid;
//    }
//
//    public void setGdqlid(String gdqlid) {
//        this.gdqlid = gdqlid;
//    }
//
//    public String getGdproid() {
//        return gdproid;
//    }
//
//    public void setGdproid(String gdproid) {
//        this.gdproid = gdproid;
//    }
//
//    public String getYbdcdyid() {
//        return ybdcdyid;
//    }
//
//    public void setYbdcdyid(String ybdcdyid) {
//        this.ybdcdyid = ybdcdyid;
//    }


    public String getYqlid() {
        return yqlid;
    }

    public void setYqlid(String yqlid) {
        this.yqlid = yqlid;
    }

    public String getRelid() {
        return relid;
    }

    public void setRelid(String relid) {
        this.relid = relid;
    }

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQjid() {
        return qjid;
    }

    public void setQjid(String qjid) {
        this.qjid = qjid;
    }

    public String getYproid() {
        return yproid;
    }

    public void setYproid(String yproid) {
        this.yproid = yproid;
    }

    public String getYdjxmly() {
        return ydjxmly;
    }

    public void setYdjxmly(String ydjxmly) {
        this.ydjxmly = ydjxmly;
    }
}

==> estateplat-common-1.2.4-20220628.015650-1056-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXmRel.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * .
 * <p/>
 * 项目关系
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-3-20
 */
@Table(name = "bdc_xm_rel")
public class BdcXmRel implements InsertVo,Serializable,BdcProid {
    @Id
    private String relid;//主键

    private String proid;//项目主键

    private String qjid;//权籍ID

    private String yproid;//原项目ID

    private String ydjxmly;//原登记项目来源 同bdcxm的xmly

    private String yqlid;//原权利ID

    private String sfzxyql;//是否注销原权利  1：不注销    0或空：注销  用于关联大土地，判断是否进行注销原权利


//zdd 暂时增加

//    private String tdid;//土地证ID
//
//    private String fwid;//房产证ID
//    private String lqid;//林权证主键
//
//    private String cqid;//草地所有权证ID
//
//    private String dyid;//抵押id
//
//    private String ygid;//预告id
//
//    private String cfid;//查封id
//
//    private String yyid;//异议id
//
//    private String gdqlid;//过渡权利id
//
//    //zdd 其他审批系统的业务主键，用于和不动产项目关联，spring aop 拦截时根据此字段是否有值进行拦截
//    private String gdproid;//过渡项目id
//
//    private String ybdcdyid;//原不动产单元id

//    public String getTdid() {
//        return tdid;
//    }
//
//    public void setTdid(String tdid) {
//        this.tdid = tdid;
//    }
//
//    public String getFwid() {
//        return fwid;
//    }
//
//    public void setFwid(String fwid) {
//        this.fwid = fwid;
//    }
//
//    public String getLqid() {
//        return lqid;
//    }
//
//    public void setLqid(String lqid) {
//        this.lqid = lqid;
//    }
//
//    public String getCqid() {
//        return cqid;
//    }
//
//    public void setCqid(String cqid) {
//        this.cqid = cqid;
//    }
//
//    public String getDyid() {
//        return dyid;
//    }
//
//    public void setDyid(String dyid) {
//        this.dyid = dyid;
//    }
//
//    public String getYgid() {
//        return ygid;
//    }
//
//    public void setYgid(String ygid) {
//        this.ygid = ygid;
//    }
//
//    public String getCfid() {
//        return cfid;
//    }
//
//    public void setCfid(String cfid) {
//        this.cfid = cfid;
//    }
//
//    public String getYyid() {
//        return yyid;
//    }
//
//    public void setYyid(String yyid) {
//        this.yyid = yyid;
//    }
//
//    public String getGdqlid() {
//        return gdqlid;
//    }
//
//    public void setGdqlid(String gdqlid) {
//        this.gdqlid = gdqlid;
//    }
//
//    public String getGdproid() {
//        return gdproid;
//    }
//
//    public void setGdproid(String gdproid) {
//        this.gdproid = gdproid;
//    }
//
//    public String getYbdcdyid() {
//        return ybdcdyid;
//    }
//
//    public void setYbdcdyid(String ybdcdyid) {
//        this.ybdcdyid = ybdcdyid;
//    }


    public String getYqlid() {
        return yqlid;
    }

    public void setYqlid(String yqlid) {
        this.yqlid = yqlid;
    }

    public String getRelid() {
        return relid;
    }

    public void setRelid(String relid) {
        this.relid = relid;
    }

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQjid() {
        return qjid;
    }

    public void setQjid(String qjid) {
        this.qjid = qjid;
    }

    public String getYproid() {
        return yproid;
    }

    public void setYproid(String yproid) {
        this.yproid = yproid;
    }

    public String getYdjxmly() {
        return ydjxmly;
    }

    public void setYdjxmly(String ydjxmly) {
        this.ydjxmly = ydjxmly;
    }

    public String getSfzxyql() {
        return sfzxyql;
    }

    public void setSfzxyql(String sfzxyql) {
        this.sfzxyql = sfzxyql;
    }
}
